#!/bin/bash

# Version 0.1

SERVER_DIR='/home/server'; # путь от сервера от корня
SERVER_ENGINE="$SERVER_DIR/engine_i486.so"; # путь до engine_i486.so [rehlds]
SERVER_MOD="$SERVER_DIR/cstrike/dlls/cs.so"; # путь до cs.so [regamedll]
SERVER_META="$SERVER_DIR/cstrike/addons/metamod/metamod_i386.so"; # путь до metamod_i386.so [metamod]
SERVER_REAPI="$SERVER_DIR/cstrike/addons/amxmodx/modules/reapi_amxx_i386.so"; # путь до reapi_amxx_i386.so [reapi]

get_rehlds()
{
	mkdir -p /tmp/rehlds;
	cd /tmp/rehlds;
	
	curl -sO http://nexus.rehlds.org/nexus/content/repositories/rehlds-dev/rehlds/rehlds/maven-metadata.xml;
	BUILD=`printf $(grep '<latest>' maven-metadata.xml | sed 's/<\/*latest>//g')`;

	curl -sO http://nexus.rehlds.org/nexus/content/repositories/rehlds-dev/rehlds/rehlds/$BUILD/rehlds-$BUILD.zip;
	
	if [ -f "rehlds-$BUILD.zip" ]
	then
		unzip rehlds-$BUILD.zip > /dev/null 2>&1;
		
		if [ -f "$SERVER_ENGINE" ]
		then
			MD5_OLD=`printf $(md5sum $SERVER_ENGINE)`;
		else
			MD5_OLD='none';
		fi
		
		MD5_NEW=`printf $(md5sum bin/linux32/engine_i486.so)`;
		
		if [[ $MD5_OLD == $MD5_NEW ]]
		then
			echo '[ReHLDS] New version not found';
		else
			mv -f bin/linux32/engine_i486.so $SERVER_ENGINE;
			
			echo "[ReHLDS] updated! New version $BUILD";
		fi
	else
		echo 'Failed download new build =(';
	fi
	
	rm -rf /tmp/rehlds;
}

get_regamedll()
{
	mkdir -p /tmp/regamedll;
	cd /tmp/regamedll;
	
	curl -sO http://nexus.rehlds.org/nexus/content/repositories/regamedll-dev/regamedll/regamedll/maven-metadata.xml;
	BUILD=`printf $(grep '<latest>' maven-metadata.xml | sed 's/<\/*latest>//g')`;

	curl -sO http://nexus.rehlds.org/nexus/content/repositories/regamedll-dev/regamedll/regamedll/$BUILD/regamedll-$BUILD.zip;
	
	if [ -f "regamedll-$BUILD.zip" ]
	then
		unzip regamedll-$BUILD.zip > /dev/null 2>&1;
		
		if [ -f "$SERVER_MOD" ]
		then
			MD5_OLD=`printf $(md5sum $SERVER_MOD)`;
		else
			MD5_OLD='none';
		fi
		
		MD5_NEW=`printf $(md5sum bin/bugfixed/cs.so)`;
		
		if [[ $MD5_OLD == $MD5_NEW ]]
		then
			echo '[ReGameDLL] New version not found';
		else
			mv -f bin/bugfixed/cs.so $SERVER_MOD;
			
			echo "[ReGameDLL] updated! New version $BUILD";
		fi
	else
		echo 'Failed download new build =(';
	fi
	
	rm -rf /tmp/regamedll;
}

get_reapi()
{
	mkdir -p /tmp/reapi;
	cd /tmp/reapi;
	
	BUILD=`curl -s http://teamcity.rehlds.org/guestAuth/app/rest/buildTypes/Reapi_Linux/builds/status:success,state:finished/id`;
	
	curl -sO http://teamcity.rehlds.org/guestAuth/repository/download/Reapi_Linux/$BUILD:id/release/reapi_amxx_i386.so;
	
	if [ -f "reapi_amxx_i386.so" ]
	then
		if [ -f "$SERVER_REAPI" ]
		then
			MD5_OLD=`printf $(md5sum $SERVER_REAPI)`;
		else
			MD5_OLD='none';
		fi
		
		MD5_NEW=`printf $(md5sum reapi_amxx_i386.so)`;
		
		if [[ $MD5_OLD == $MD5_NEW ]]
		then
			echo '[ReAPI] New version not found';
		else
			mv -f reapi_amxx_i386.so $SERVER_REAPI;
			
			BUILD=`curl -s http://teamcity.rehlds.org/guestAuth/app/rest/buildTypes/Reapi_Linux/builds/status:success,state:finished/number`;
			echo "[ReAPI] updated! New version $BUILD";
		fi
	else
		echo 'Failed download new build =(';
	fi
	
	rm -rf /tmp/reapi;	
}

get_metamod()
{
	mkdir -p /tmp/metamod;
	cd /tmp/metamod;
	
	BUILD=`curl -s http://teamcity.rehlds.org/guestAuth/app/rest/buildTypes/Metamod_Linux/builds/status:success,state:finished/id`;
	
	curl -sO http://teamcity.rehlds.org/guestAuth/repository/download/Metamod_Linux/$BUILD:id/release/libmetamod_i386.so;
	
	if [ -f "libmetamod_i386.so" ]
	then
		if [ -f "$SERVER_META" ]
		then
			MD5_OLD=`printf $(md5sum $SERVER_META)`;
		else
			MD5_OLD='none';
		fi
		
		MD5_NEW=`printf $(md5sum libmetamod_i386.so)`;
		
		if [[ $MD5_OLD == $MD5_NEW ]]
		then
			echo '[MetaMod] New version not found';
		else
			mv -f libmetamod_i386.so $SERVER_META;
			
			BUILD=`curl -s http://teamcity.rehlds.org/guestAuth/app/rest/buildTypes/Metamod_Linux/builds/status:success,state:finished/number`;
			echo "[MetaMod] updated! New version $BUILD";
		fi
	else
		echo 'Failed download new build =(';
	fi
	
	rm -rf /tmp/metamod;
}

case $1 in
	rehlds)
		get_rehlds;
	;;
	regamedll)
		get_regamedll;
	;;
	reapi)
		get_reapi;
	;;
	metamod)
		get_metamod;
	;;
	all)
		get_rehlds;
		get_regamedll;
		get_reapi;
		get_metamod;
	;;
*)
echo "Usage $0 rehlds|regamedll|reapi|metamod|all"
esac;
